function segments = perform_synchronized_segmentation(y, fs, num_periods)

% segments = perform_synchronized_segmentation(y, fs, num_periods)
% 
% This function provides the pitch-synchronized segmentation using the
% algorithm pitch_marks written by W. Goncharoff (goncharo@ece.uic.edu).
% 
% y             - input signal in column vector
% fs            - sampling frequency
% num_periods   - number of periods in each segment (default: 3)
% segments      - output cell array with segments

%% Paths and variables
if ((nargin < 3) || (isempty(num_periods)))
    num_periods = 3;
end

%% Find the pitch marks
pitch_marks = find_pmarks(y, fs);

%% Segment the signal according to periods
segments = cell(1, fix((length(pitch_marks) - 1)/num_periods));

for i = 1:size(segments, 2)
    brd_left  = num_periods*(i - 1) + 1;
    brd_right = brd_left + num_periods;
    
    segments{1, i} = y(pitch_marks(brd_left):pitch_marks(brd_right) - 1);
end